# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MergePullRequestOption(BaseModel):
    """
    MergePullRequestForm form for merging Pull Request
    """ # noqa: E501
    do: StrictStr = Field(alias="Do")
    merge_commit_id: Optional[StrictStr] = Field(default=None, alias="MergeCommitID")
    merge_message_field: Optional[StrictStr] = Field(default=None, alias="MergeMessageField")
    merge_title_field: Optional[StrictStr] = Field(default=None, alias="MergeTitleField")
    delete_branch_after_merge: Optional[StrictBool] = None
    force_merge: Optional[StrictBool] = None
    head_commit_id: Optional[StrictStr] = None
    merge_when_checks_succeed: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["Do", "MergeCommitID", "MergeMessageField", "MergeTitleField", "delete_branch_after_merge", "force_merge", "head_commit_id", "merge_when_checks_succeed"]

    @field_validator('do')
    def do_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['merge', 'rebase', 'rebase-merge', 'squash', 'fast-forward-only', 'manually-merged']):
            raise ValueError("must be one of enum values ('merge', 'rebase', 'rebase-merge', 'squash', 'fast-forward-only', 'manually-merged')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MergePullRequestOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MergePullRequestOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "Do": obj.get("Do"),
            "MergeCommitID": obj.get("MergeCommitID"),
            "MergeMessageField": obj.get("MergeMessageField"),
            "MergeTitleField": obj.get("MergeTitleField"),
            "delete_branch_after_merge": obj.get("delete_branch_after_merge"),
            "force_merge": obj.get("force_merge"),
            "head_commit_id": obj.get("head_commit_id"),
            "merge_when_checks_succeed": obj.get("merge_when_checks_succeed")
        })
        return _obj





# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.update_file_options import (
    UpdateFileOptions,
)  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestUpdateFileOptions(unittest.TestCase):
    """UpdateFileOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpdateFileOptions
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `UpdateFileOptions`
        """
        model = py_gitea_opensuse_org.models.update_file_options.UpdateFileOptions()  # noqa: E501
        if include_optional :
            return UpdateFileOptions(
                author = py_gitea_opensuse_org.models.identity.Identity(
                    email = '', 
                    name = '', ), 
                branch = '', 
                committer = py_gitea_opensuse_org.models.identity.Identity(
                    email = '', 
                    name = '', ), 
                content = '', 
                dates = py_gitea_opensuse_org.models.commit_date_options.CommitDateOptions(
                    author = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    committer = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                from_path = '', 
                message = '', 
                new_branch = '', 
                sha = '', 
                signoff = True
            )
        else :
            return UpdateFileOptions(
                content = '',
                sha = '',
        )
        """

    def testUpdateFileOptions(self):
        """Test UpdateFileOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.contents_ext_response import ContentsExtResponse

class TestContentsExtResponse(unittest.TestCase):
    """ContentsExtResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContentsExtResponse:
        """Test ContentsExtResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContentsExtResponse`
        """
        model = ContentsExtResponse()
        if include_optional:
            return ContentsExtResponse(
                dir_contents = [
                    py_gitea_opensuse_org.models.contents_response.ContentsResponse(
                        _links = py_gitea_opensuse_org.models.file_links_response.FileLinksResponse(
                            git = '', 
                            html = '', 
                            self = '', ), 
                        content = '', 
                        download_url = '', 
                        encoding = '', 
                        git_url = '', 
                        html_url = '', 
                        last_author_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_commit_message = '', 
                        last_commit_sha = '', 
                        last_committer_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        lfs_oid = '', 
                        lfs_size = 56, 
                        name = '', 
                        path = '', 
                        sha = '', 
                        size = 56, 
                        submodule_git_url = '', 
                        target = '', 
                        type = '', 
                        url = '', )
                    ],
                file_contents = py_gitea_opensuse_org.models.contents_response.ContentsResponse(
                    _links = py_gitea_opensuse_org.models.file_links_response.FileLinksResponse(
                        git = '', 
                        html = '', 
                        self = '', ), 
                    content = '', 
                    download_url = '', 
                    encoding = '', 
                    git_url = '', 
                    html_url = '', 
                    last_author_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_commit_message = '', 
                    last_commit_sha = '', 
                    last_committer_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    lfs_oid = '', 
                    lfs_size = 56, 
                    name = '', 
                    path = '', 
                    sha = '', 
                    size = 56, 
                    submodule_git_url = '', 
                    target = '', 
                    type = '', 
                    url = '', )
            )
        else:
            return ContentsExtResponse(
        )
        """

    def testContentsExtResponse(self):
        """Test ContentsExtResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.payload_commit import PayloadCommit
from typing import Optional, Set
from typing_extensions import Self

class Branch(BaseModel):
    """
    Branch represents a repository branch
    """ # noqa: E501
    commit: Optional[PayloadCommit] = None
    effective_branch_protection_name: Optional[StrictStr] = Field(default=None, description="EffectiveBranchProtectionName is the name of the effective branch protection rule")
    enable_status_check: Optional[StrictBool] = Field(default=None, description="EnableStatusCheck indicates if status checks are enabled")
    name: Optional[StrictStr] = Field(default=None, description="Name is the branch name")
    protected: Optional[StrictBool] = Field(default=None, description="Protected indicates if the branch is protected")
    required_approvals: Optional[StrictInt] = Field(default=None, description="RequiredApprovals is the number of required approvals for pull requests")
    status_check_contexts: Optional[List[StrictStr]] = Field(default=None, description="StatusCheckContexts contains the list of required status check contexts")
    user_can_merge: Optional[StrictBool] = Field(default=None, description="UserCanMerge indicates if the current user can merge to this branch")
    user_can_push: Optional[StrictBool] = Field(default=None, description="UserCanPush indicates if the current user can push to this branch")
    __properties: ClassVar[List[str]] = ["commit", "effective_branch_protection_name", "enable_status_check", "name", "protected", "required_approvals", "status_check_contexts", "user_can_merge", "user_can_push"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Branch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of commit
        if self.commit:
            _dict['commit'] = self.commit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Branch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "commit": PayloadCommit.from_dict(obj["commit"]) if obj.get("commit") is not None else None,
            "effective_branch_protection_name": obj.get("effective_branch_protection_name"),
            "enable_status_check": obj.get("enable_status_check"),
            "name": obj.get("name"),
            "protected": obj.get("protected"),
            "required_approvals": obj.get("required_approvals"),
            "status_check_contexts": obj.get("status_check_contexts"),
            "user_can_merge": obj.get("user_can_merge"),
            "user_can_push": obj.get("user_can_push")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class EditPullRequestOption(BaseModel):
    """
    EditPullRequestOption options when modify pull request
    """ # noqa: E501
    allow_maintainer_edit: Optional[StrictBool] = Field(default=None, description="Whether to allow maintainer edits")
    assignee: Optional[StrictStr] = Field(default=None, description="The new primary assignee username")
    assignees: Optional[List[StrictStr]] = Field(default=None, description="The new list of assignee usernames")
    base: Optional[StrictStr] = Field(default=None, description="The new base branch for the pull request")
    body: Optional[StrictStr] = Field(default=None, description="The new description body for the pull request")
    due_date: Optional[datetime] = None
    labels: Optional[List[StrictInt]] = Field(default=None, description="The new list of label IDs for the pull request")
    milestone: Optional[StrictInt] = Field(default=None, description="The new milestone ID for the pull request")
    state: Optional[StrictStr] = Field(default=None, description="The new state for the pull request")
    title: Optional[StrictStr] = Field(default=None, description="The new title for the pull request")
    unset_due_date: Optional[StrictBool] = Field(default=None, description="Whether to remove the current deadline")
    __properties: ClassVar[List[str]] = ["allow_maintainer_edit", "assignee", "assignees", "base", "body", "due_date", "labels", "milestone", "state", "title", "unset_due_date"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EditPullRequestOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EditPullRequestOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_maintainer_edit": obj.get("allow_maintainer_edit"),
            "assignee": obj.get("assignee"),
            "assignees": obj.get("assignees"),
            "base": obj.get("base"),
            "body": obj.get("body"),
            "due_date": obj.get("due_date"),
            "labels": obj.get("labels"),
            "milestone": obj.get("milestone"),
            "state": obj.get("state"),
            "title": obj.get("title"),
            "unset_due_date": obj.get("unset_due_date")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Milestone(BaseModel):
    """
    Milestone milestone is a collection of issues on one repository
    """ # noqa: E501
    closed_at: Optional[datetime] = None
    closed_issues: Optional[StrictInt] = Field(default=None, description="ClosedIssues is the number of closed issues in this milestone")
    created_at: Optional[datetime] = None
    description: Optional[StrictStr] = Field(default=None, description="Description provides details about the milestone")
    due_on: Optional[datetime] = None
    id: Optional[StrictInt] = Field(default=None, description="ID is the unique identifier for the milestone")
    open_issues: Optional[StrictInt] = Field(default=None, description="OpenIssues is the number of open issues in this milestone")
    state: Optional[StrictStr] = Field(default=None, description="StateType issue state type")
    title: Optional[StrictStr] = Field(default=None, description="Title is the title of the milestone")
    updated_at: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["closed_at", "closed_issues", "created_at", "description", "due_on", "id", "open_issues", "state", "title", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Milestone from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Milestone from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "closed_at": obj.get("closed_at"),
            "closed_issues": obj.get("closed_issues"),
            "created_at": obj.get("created_at"),
            "description": obj.get("description"),
            "due_on": obj.get("due_on"),
            "id": obj.get("id"),
            "open_issues": obj.get("open_issues"),
            "state": obj.get("state"),
            "title": obj.get("title"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.wiki_commit import WikiCommit
from typing import Optional, Set
from typing_extensions import Self

class WikiPage(BaseModel):
    """
    WikiPage a wiki page
    """ # noqa: E501
    commit_count: Optional[StrictInt] = Field(default=None, description="The number of commits that modified this page")
    content_base64: Optional[StrictStr] = Field(default=None, description="Page content, base64 encoded")
    footer: Optional[StrictStr] = Field(default=None, description="The footer content for the wiki page")
    html_url: Optional[StrictStr] = Field(default=None, description="The HTML URL to view the wiki page")
    last_commit: Optional[WikiCommit] = None
    sidebar: Optional[StrictStr] = Field(default=None, description="The sidebar content for the wiki page")
    sub_url: Optional[StrictStr] = Field(default=None, description="The sub URL path for the wiki page")
    title: Optional[StrictStr] = Field(default=None, description="The title of the wiki page")
    __properties: ClassVar[List[str]] = ["commit_count", "content_base64", "footer", "html_url", "last_commit", "sidebar", "sub_url", "title"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WikiPage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of last_commit
        if self.last_commit:
            _dict['last_commit'] = self.last_commit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WikiPage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "commit_count": obj.get("commit_count"),
            "content_base64": obj.get("content_base64"),
            "footer": obj.get("footer"),
            "html_url": obj.get("html_url"),
            "last_commit": WikiCommit.from_dict(obj["last_commit"]) if obj.get("last_commit") is not None else None,
            "sidebar": obj.get("sidebar"),
            "sub_url": obj.get("sub_url"),
            "title": obj.get("title")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.node_info_services import NodeInfoServices
from py_gitea_opensuse_org.models.node_info_software import NodeInfoSoftware
from py_gitea_opensuse_org.models.node_info_usage import NodeInfoUsage
from typing import Optional, Set
from typing_extensions import Self

class NodeInfo(BaseModel):
    """
    NodeInfo contains standardized way of exposing metadata about a server running one of the distributed social networks
    """ # noqa: E501
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Metadata contains free form key value pairs for software specific values")
    open_registrations: Optional[StrictBool] = Field(default=None, description="OpenRegistrations indicates if new user registrations are accepted", alias="openRegistrations")
    protocols: Optional[List[StrictStr]] = Field(default=None, description="Protocols lists the protocols supported by this server")
    services: Optional[NodeInfoServices] = None
    software: Optional[NodeInfoSoftware] = None
    usage: Optional[NodeInfoUsage] = None
    version: Optional[StrictStr] = Field(default=None, description="Version specifies the schema version")
    __properties: ClassVar[List[str]] = ["metadata", "openRegistrations", "protocols", "services", "software", "usage", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NodeInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of services
        if self.services:
            _dict['services'] = self.services.to_dict()
        # override the default output from pydantic by calling `to_dict()` of software
        if self.software:
            _dict['software'] = self.software.to_dict()
        # override the default output from pydantic by calling `to_dict()` of usage
        if self.usage:
            _dict['usage'] = self.usage.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NodeInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "metadata": obj.get("metadata"),
            "openRegistrations": obj.get("openRegistrations"),
            "protocols": obj.get("protocols"),
            "services": NodeInfoServices.from_dict(obj["services"]) if obj.get("services") is not None else None,
            "software": NodeInfoSoftware.from_dict(obj["software"]) if obj.get("software") is not None else None,
            "usage": NodeInfoUsage.from_dict(obj["usage"]) if obj.get("usage") is not None else None,
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_workflow_jobs_response import ActionWorkflowJobsResponse

class TestActionWorkflowJobsResponse(unittest.TestCase):
    """ActionWorkflowJobsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionWorkflowJobsResponse:
        """Test ActionWorkflowJobsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionWorkflowJobsResponse`
        """
        model = ActionWorkflowJobsResponse()
        if include_optional:
            return ActionWorkflowJobsResponse(
                jobs = [
                    py_gitea_opensuse_org.models.action_workflow_job.ActionWorkflowJob(
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conclusion = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        head_branch = '', 
                        head_sha = '', 
                        html_url = '', 
                        id = 56, 
                        labels = [
                            ''
                            ], 
                        name = '', 
                        run_attempt = 56, 
                        run_id = 56, 
                        run_url = '', 
                        runner_id = 56, 
                        runner_name = '', 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', 
                        steps = [
                            py_gitea_opensuse_org.models.action_workflow_step.ActionWorkflowStep(
                                completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                conclusion = '', 
                                name = '', 
                                number = 56, 
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                status = '', )
                            ], 
                        url = '', )
                    ],
                total_count = 56
            )
        else:
            return ActionWorkflowJobsResponse(
        )
        """

    def testActionWorkflowJobsResponse(self):
        """Test ActionWorkflowJobsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.create_tag_protection_option import CreateTagProtectionOption

class TestCreateTagProtectionOption(unittest.TestCase):
    """CreateTagProtectionOption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateTagProtectionOption:
        """Test CreateTagProtectionOption
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateTagProtectionOption`
        """
        model = CreateTagProtectionOption()
        if include_optional:
            return CreateTagProtectionOption(
                name_pattern = '',
                whitelist_teams = [
                    ''
                    ],
                whitelist_usernames = [
                    ''
                    ]
            )
        else:
            return CreateTagProtectionOption(
        )
        """

    def testCreateTagProtectionOption(self):
        """Test CreateTagProtectionOption"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.repository import Repository
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class ActionWorkflowRun(BaseModel):
    """
    ActionWorkflowRun represents a WorkflowRun
    """ # noqa: E501
    actor: Optional[User] = None
    completed_at: Optional[datetime] = None
    conclusion: Optional[StrictStr] = None
    display_title: Optional[StrictStr] = None
    event: Optional[StrictStr] = None
    head_branch: Optional[StrictStr] = None
    head_repository: Optional[Repository] = None
    head_sha: Optional[StrictStr] = None
    html_url: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    path: Optional[StrictStr] = None
    repository: Optional[Repository] = None
    repository_id: Optional[StrictInt] = None
    run_attempt: Optional[StrictInt] = None
    run_number: Optional[StrictInt] = None
    started_at: Optional[datetime] = None
    status: Optional[StrictStr] = None
    trigger_actor: Optional[User] = None
    url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["actor", "completed_at", "conclusion", "display_title", "event", "head_branch", "head_repository", "head_sha", "html_url", "id", "path", "repository", "repository_id", "run_attempt", "run_number", "started_at", "status", "trigger_actor", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ActionWorkflowRun from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of actor
        if self.actor:
            _dict['actor'] = self.actor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of head_repository
        if self.head_repository:
            _dict['head_repository'] = self.head_repository.to_dict()
        # override the default output from pydantic by calling `to_dict()` of repository
        if self.repository:
            _dict['repository'] = self.repository.to_dict()
        # override the default output from pydantic by calling `to_dict()` of trigger_actor
        if self.trigger_actor:
            _dict['trigger_actor'] = self.trigger_actor.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ActionWorkflowRun from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "actor": User.from_dict(obj["actor"]) if obj.get("actor") is not None else None,
            "completed_at": obj.get("completed_at"),
            "conclusion": obj.get("conclusion"),
            "display_title": obj.get("display_title"),
            "event": obj.get("event"),
            "head_branch": obj.get("head_branch"),
            "head_repository": Repository.from_dict(obj["head_repository"]) if obj.get("head_repository") is not None else None,
            "head_sha": obj.get("head_sha"),
            "html_url": obj.get("html_url"),
            "id": obj.get("id"),
            "path": obj.get("path"),
            "repository": Repository.from_dict(obj["repository"]) if obj.get("repository") is not None else None,
            "repository_id": obj.get("repository_id"),
            "run_attempt": obj.get("run_attempt"),
            "run_number": obj.get("run_number"),
            "started_at": obj.get("started_at"),
            "status": obj.get("status"),
            "trigger_actor": User.from_dict(obj["trigger_actor"]) if obj.get("trigger_actor") is not None else None,
            "url": obj.get("url")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.commit_status import CommitStatus
from py_gitea_opensuse_org.models.repository import Repository
from typing import Optional, Set
from typing_extensions import Self

class CombinedStatus(BaseModel):
    """
    CombinedStatus holds the combined state of several statuses for a single commit
    """ # noqa: E501
    commit_url: Optional[StrictStr] = Field(default=None, description="CommitURL is the API URL for the commit")
    repository: Optional[Repository] = None
    sha: Optional[StrictStr] = Field(default=None, description="SHA is the commit SHA this status applies to")
    state: Optional[StrictStr] = Field(default=None, description="State is the overall combined status state pending CommitStatusPending  CommitStatusPending is for when the CommitStatus is Pending success CommitStatusSuccess  CommitStatusSuccess is for when the CommitStatus is Success error CommitStatusError  CommitStatusError is for when the CommitStatus is Error failure CommitStatusFailure  CommitStatusFailure is for when the CommitStatus is Failure warning CommitStatusWarning  CommitStatusWarning is for when the CommitStatus is Warning skipped CommitStatusSkipped  CommitStatusSkipped is for when CommitStatus is Skipped")
    statuses: Optional[List[CommitStatus]] = Field(default=None, description="Statuses contains all individual commit statuses")
    total_count: Optional[StrictInt] = Field(default=None, description="TotalCount is the total number of statuses")
    url: Optional[StrictStr] = Field(default=None, description="URL is the API URL for this combined status")
    __properties: ClassVar[List[str]] = ["commit_url", "repository", "sha", "state", "statuses", "total_count", "url"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['pending', 'success', 'error', 'failure', 'warning', 'skipped']):
            raise ValueError("must be one of enum values ('pending', 'success', 'error', 'failure', 'warning', 'skipped')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CombinedStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of repository
        if self.repository:
            _dict['repository'] = self.repository.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in statuses (list)
        _items = []
        if self.statuses:
            for _item_statuses in self.statuses:
                if _item_statuses:
                    _items.append(_item_statuses.to_dict())
            _dict['statuses'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CombinedStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "commit_url": obj.get("commit_url"),
            "repository": Repository.from_dict(obj["repository"]) if obj.get("repository") is not None else None,
            "sha": obj.get("sha"),
            "state": obj.get("state"),
            "statuses": [CommitStatus.from_dict(_item) for _item in obj["statuses"]] if obj.get("statuses") is not None else None,
            "total_count": obj.get("total_count"),
            "url": obj.get("url")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class CommitStatus(BaseModel):
    """
    CommitStatus holds a single status of a single Commit
    """ # noqa: E501
    context: Optional[StrictStr] = Field(default=None, description="Context is the unique context identifier for the status")
    created_at: Optional[datetime] = None
    creator: Optional[User] = None
    description: Optional[StrictStr] = Field(default=None, description="Description provides a brief description of the status")
    id: Optional[StrictInt] = Field(default=None, description="ID is the unique identifier for the commit status")
    status: Optional[StrictStr] = Field(default=None, description="State represents the status state (pending, success, error, failure) pending CommitStatusPending  CommitStatusPending is for when the CommitStatus is Pending success CommitStatusSuccess  CommitStatusSuccess is for when the CommitStatus is Success error CommitStatusError  CommitStatusError is for when the CommitStatus is Error failure CommitStatusFailure  CommitStatusFailure is for when the CommitStatus is Failure warning CommitStatusWarning  CommitStatusWarning is for when the CommitStatus is Warning skipped CommitStatusSkipped  CommitStatusSkipped is for when CommitStatus is Skipped")
    target_url: Optional[StrictStr] = Field(default=None, description="TargetURL is the URL to link to for more details")
    updated_at: Optional[datetime] = None
    url: Optional[StrictStr] = Field(default=None, description="URL is the API URL for this status")
    __properties: ClassVar[List[str]] = ["context", "created_at", "creator", "description", "id", "status", "target_url", "updated_at", "url"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['pending', 'success', 'error', 'failure', 'warning', 'skipped']):
            raise ValueError("must be one of enum values ('pending', 'success', 'error', 'failure', 'warning', 'skipped')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CommitStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of creator
        if self.creator:
            _dict['creator'] = self.creator.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CommitStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "context": obj.get("context"),
            "created_at": obj.get("created_at"),
            "creator": User.from_dict(obj["creator"]) if obj.get("creator") is not None else None,
            "description": obj.get("description"),
            "id": obj.get("id"),
            "status": obj.get("status"),
            "target_url": obj.get("target_url"),
            "updated_at": obj.get("updated_at"),
            "url": obj.get("url")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.attachment import Attachment
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Release(BaseModel):
    """
    Release represents a repository release
    """ # noqa: E501
    assets: Optional[List[Attachment]] = Field(default=None, description="The files attached to the release")
    author: Optional[User] = None
    body: Optional[StrictStr] = Field(default=None, description="The release notes or description")
    created_at: Optional[datetime] = None
    draft: Optional[StrictBool] = Field(default=None, description="Whether the release is a draft")
    html_url: Optional[StrictStr] = Field(default=None, description="The HTML URL to view the release")
    id: Optional[StrictInt] = Field(default=None, description="The unique identifier of the release")
    name: Optional[StrictStr] = Field(default=None, description="The display title of the release")
    prerelease: Optional[StrictBool] = Field(default=None, description="Whether the release is a prerelease")
    published_at: Optional[datetime] = None
    tag_name: Optional[StrictStr] = Field(default=None, description="The name of the git tag associated with the release")
    tarball_url: Optional[StrictStr] = Field(default=None, description="The URL to download the tarball archive")
    target_commitish: Optional[StrictStr] = Field(default=None, description="The target commitish for the release")
    upload_url: Optional[StrictStr] = Field(default=None, description="The URL template for uploading release assets")
    url: Optional[StrictStr] = Field(default=None, description="The API URL of the release")
    zipball_url: Optional[StrictStr] = Field(default=None, description="The URL to download the zip archive")
    __properties: ClassVar[List[str]] = ["assets", "author", "body", "created_at", "draft", "html_url", "id", "name", "prerelease", "published_at", "tag_name", "tarball_url", "target_commitish", "upload_url", "url", "zipball_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Release from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in assets (list)
        _items = []
        if self.assets:
            for _item_assets in self.assets:
                if _item_assets:
                    _items.append(_item_assets.to_dict())
            _dict['assets'] = _items
        # override the default output from pydantic by calling `to_dict()` of author
        if self.author:
            _dict['author'] = self.author.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Release from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "assets": [Attachment.from_dict(_item) for _item in obj["assets"]] if obj.get("assets") is not None else None,
            "author": User.from_dict(obj["author"]) if obj.get("author") is not None else None,
            "body": obj.get("body"),
            "created_at": obj.get("created_at"),
            "draft": obj.get("draft"),
            "html_url": obj.get("html_url"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "prerelease": obj.get("prerelease"),
            "published_at": obj.get("published_at"),
            "tag_name": obj.get("tag_name"),
            "tarball_url": obj.get("tarball_url"),
            "target_commitish": obj.get("target_commitish"),
            "upload_url": obj.get("upload_url"),
            "url": obj.get("url"),
            "zipball_url": obj.get("zipball_url")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreatePullRequestOption(BaseModel):
    """
    CreatePullRequestOption options when creating a pull request
    """ # noqa: E501
    assignee: Optional[StrictStr] = Field(default=None, description="The primary assignee username")
    assignees: Optional[List[StrictStr]] = Field(default=None, description="The list of assignee usernames")
    base: Optional[StrictStr] = Field(default=None, description="The base branch for the pull request")
    body: Optional[StrictStr] = Field(default=None, description="The description body of the pull request")
    due_date: Optional[datetime] = None
    head: Optional[StrictStr] = Field(default=None, description="The head branch for the pull request, it could be a branch name on the base repository or a form like `<username>:<branch>` which refers to the user's fork repository's branch.")
    labels: Optional[List[StrictInt]] = Field(default=None, description="The list of label IDs to assign to the pull request")
    milestone: Optional[StrictInt] = Field(default=None, description="The milestone ID to assign to the pull request")
    reviewers: Optional[List[StrictStr]] = Field(default=None, description="The list of reviewer usernames")
    team_reviewers: Optional[List[StrictStr]] = Field(default=None, description="The list of team reviewer names")
    title: Optional[StrictStr] = Field(default=None, description="The title of the pull request")
    __properties: ClassVar[List[str]] = ["assignee", "assignees", "base", "body", "due_date", "head", "labels", "milestone", "reviewers", "team_reviewers", "title"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreatePullRequestOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreatePullRequestOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "assignee": obj.get("assignee"),
            "assignees": obj.get("assignees"),
            "base": obj.get("base"),
            "body": obj.get("body"),
            "due_date": obj.get("due_date"),
            "head": obj.get("head"),
            "labels": obj.get("labels"),
            "milestone": obj.get("milestone"),
            "reviewers": obj.get("reviewers"),
            "team_reviewers": obj.get("team_reviewers"),
            "title": obj.get("title")
        })
        return _obj





# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_workflow_runs_response import ActionWorkflowRunsResponse

class TestActionWorkflowRunsResponse(unittest.TestCase):
    """ActionWorkflowRunsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionWorkflowRunsResponse:
        """Test ActionWorkflowRunsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionWorkflowRunsResponse`
        """
        model = ActionWorkflowRunsResponse()
        if include_optional:
            return ActionWorkflowRunsResponse(
                total_count = 56,
                workflow_runs = [
                    py_gitea_opensuse_org.models.action_workflow_run.ActionWorkflowRun(
                        actor = py_gitea_opensuse_org.models.user.User(
                            active = True, 
                            avatar_url = '', 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            email = '', 
                            followers_count = 56, 
                            following_count = 56, 
                            full_name = '', 
                            html_url = '', 
                            id = 56, 
                            is_admin = True, 
                            language = '', 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            location = '', 
                            login = '', 
                            login_name = 'empty', 
                            prohibit_login = True, 
                            restricted = True, 
                            source_id = 56, 
                            starred_repos_count = 56, 
                            visibility = '', 
                            website = '', ), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conclusion = '', 
                        display_title = '', 
                        event = '', 
                        head_branch = '', 
                        head_repository = py_gitea_opensuse_org.models.repository.Repository(
                            allow_fast_forward_only_merge = True, 
                            allow_manual_merge = True, 
                            allow_merge_commits = True, 
                            allow_rebase = True, 
                            allow_rebase_explicit = True, 
                            allow_rebase_update = True, 
                            allow_squash_merge = True, 
                            archived = True, 
                            archived_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            autodetect_manual_merge = True, 
                            avatar_url = '', 
                            clone_url = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            default_allow_maintainer_edit = True, 
                            default_branch = '', 
                            default_delete_branch_after_merge = True, 
                            default_merge_style = '', 
                            description = '', 
                            empty = True, 
                            external_tracker = py_gitea_opensuse_org.models.external_tracker.ExternalTracker(
                                external_tracker_format = '', 
                                external_tracker_regexp_pattern = '', 
                                external_tracker_style = '', 
                                external_tracker_url = '', ), 
                            external_wiki = py_gitea_opensuse_org.models.external_wiki.ExternalWiki(
                                external_wiki_url = '', ), 
                            fork = True, 
                            forks_count = 56, 
                            full_name = '', 
                            has_actions = True, 
                            has_code = True, 
                            has_issues = True, 
                            has_packages = True, 
                            has_projects = True, 
                            has_pull_requests = True, 
                            has_releases = True, 
                            has_wiki = True, 
                            html_url = '', 
                            id = 56, 
                            ignore_whitespace_conflicts = True, 
                            internal = True, 
                            internal_tracker = py_gitea_opensuse_org.models.internal_tracker.InternalTracker(
                                allow_only_contributors_to_track_time = True, 
                                enable_issue_dependencies = True, 
                                enable_time_tracker = True, ), 
                            language = '', 
                            languages_url = '', 
                            licenses = [
                                ''
                                ], 
                            link = '', 
                            mirror = True, 
                            mirror_interval = '', 
                            mirror_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            object_format_name = 'sha1', 
                            open_issues_count = 56, 
                            open_pr_counter = 56, 
                            original_url = '', 
                            owner = py_gitea_opensuse_org.models.user.User(
                                active = True, 
                                avatar_url = '', 
                                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                description = '', 
                                email = '', 
                                followers_count = 56, 
                                following_count = 56, 
                                full_name = '', 
                                html_url = '', 
                                id = 56, 
                                is_admin = True, 
                                language = '', 
                                last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                location = '', 
                                login = '', 
                                login_name = 'empty', 
                                prohibit_login = True, 
                                restricted = True, 
                                source_id = 56, 
                                starred_repos_count = 56, 
                                visibility = '', 
                                website = '', ), 
                            parent = py_gitea_opensuse_org.models.repository.Repository(
                                allow_fast_forward_only_merge = True, 
                                allow_manual_merge = True, 
                                allow_merge_commits = True, 
                                allow_rebase = True, 
                                allow_rebase_explicit = True, 
                                allow_rebase_update = True, 
                                allow_squash_merge = True, 
                                archived = True, 
                                archived_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                autodetect_manual_merge = True, 
                                avatar_url = '', 
                                clone_url = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                default_allow_maintainer_edit = True, 
                                default_branch = '', 
                                default_delete_branch_after_merge = True, 
                                default_merge_style = '', 
                                description = '', 
                                empty = True, 
                                fork = True, 
                                forks_count = 56, 
                                full_name = '', 
                                has_actions = True, 
                                has_code = True, 
                                has_issues = True, 
                                has_packages = True, 
                                has_projects = True, 
                                has_pull_requests = True, 
                                has_releases = True, 
                                has_wiki = True, 
                                html_url = '', 
                                id = 56, 
                                ignore_whitespace_conflicts = True, 
                                internal = True, 
                                language = '', 
                                languages_url = '', 
                                link = '', 
                                mirror = True, 
                                mirror_interval = '', 
                                mirror_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                object_format_name = 'sha1', 
                                open_issues_count = 56, 
                                open_pr_counter = 56, 
                                original_url = '', 
                                permissions = py_gitea_opensuse_org.models.permission.Permission(
                                    admin = True, 
                                    pull = True, 
                                    push = True, ), 
                                private = True, 
                                projects_mode = '', 
                                release_counter = 56, 
                                repo_transfer = py_gitea_opensuse_org.models.repo_transfer.RepoTransfer(
                                    doer = , 
                                    recipient = , 
                                    teams = [
                                        py_gitea_opensuse_org.models.team.Team(
                                            can_create_org_repo = True, 
                                            description = '', 
                                            id = 56, 
                                            includes_all_repositories = True, 
                                            name = '', 
                                            organization = py_gitea_opensuse_org.models.organization.Organization(
                                                avatar_url = '', 
                                                description = '', 
                                                email = '', 
                                                full_name = '', 
                                                id = 56, 
                                                location = '', 
                                                name = '', 
                                                repo_admin_change_team_access = True, 
                                                username = '', 
                                                visibility = '', 
                                                website = '', ), 
                                            permission = 'none', 
                                            units = [repo.code, repo.issues, repo.ext_issues, repo.wiki, repo.pulls, repo.releases, repo.projects, repo.ext_wiki], 
                                            units_map = {"repo.code":"read","repo.ext_issues":"none","repo.ext_wiki":"none","repo.issues":"write","repo.projects":"none","repo.pulls":"owner","repo.releases":"none","repo.wiki":"admin"}, )
                                        ], ), 
                                size = 56, 
                                ssh_url = '', 
                                stars_count = 56, 
                                template = True, 
                                topics = [
                                    ''
                                    ], 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                url = '', 
                                watchers_count = 56, 
                                website = '', ), 
                            permissions = py_gitea_opensuse_org.models.permission.Permission(
                                admin = True, 
                                pull = True, 
                                push = True, ), 
                            private = True, 
                            projects_mode = '', 
                            release_counter = 56, 
                            repo_transfer = py_gitea_opensuse_org.models.repo_transfer.RepoTransfer(), 
                            size = 56, 
                            ssh_url = '', 
                            stars_count = 56, 
                            template = True, 
                            topics = [
                                ''
                                ], 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            url = '', 
                            watchers_count = 56, 
                            website = '', ), 
                        head_sha = '', 
                        html_url = '', 
                        id = 56, 
                        path = '', 
                        repository = , 
                        repository_id = 56, 
                        run_attempt = 56, 
                        run_number = 56, 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', 
                        trigger_actor = , 
                        url = '', )
                    ]
            )
        else:
            return ActionWorkflowRunsResponse(
        )
        """

    def testActionWorkflowRunsResponse(self):
        """Test ActionWorkflowRunsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.pull_review import PullReview  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestPullReview(unittest.TestCase):
    """PullReview unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PullReview
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PullReview`
        """
        model = py_gitea_opensuse_org.models.pull_review.PullReview()  # noqa: E501
        if include_optional :
            return PullReview(
                body = '', 
                comments_count = 56, 
                commit_id = '', 
                dismissed = True, 
                html_url = '', 
                id = 56, 
                official = True, 
                pull_request_url = '', 
                stale = True, 
                state = '', 
                submitted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                team = py_gitea_opensuse_org.models.team.Team(
                    can_create_org_repo = True, 
                    description = '', 
                    id = 56, 
                    includes_all_repositories = True, 
                    name = '', 
                    organization = py_gitea_opensuse_org.models.organization.Organization(
                        avatar_url = '', 
                        description = '', 
                        full_name = '', 
                        id = 56, 
                        location = '', 
                        name = '', 
                        repo_admin_change_team_access = True, 
                        username = '', 
                        visibility = '', 
                        website = '', ), 
                    permission = 'none', 
                    units = [repo.code, repo.issues, repo.ext_issues, repo.wiki, repo.pulls, repo.releases, repo.projects, repo.ext_wiki], 
                    units_map = {"repo.code":"read","repo.ext_issues":"none","repo.ext_wiki":"none","repo.issues":"write","repo.projects":"none","repo.pulls":"owner","repo.releases":"none","repo.wiki":"admin"}, ), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                user = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', )
            )
        else :
            return PullReview(
        )
        """

    def testPullReview(self):
        """Test PullReview"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.payload_commit_verification import PayloadCommitVerification
from py_gitea_opensuse_org.models.payload_user import PayloadUser
from typing import Optional, Set
from typing_extensions import Self

class PayloadCommit(BaseModel):
    """
    PayloadCommit represents a commit
    """ # noqa: E501
    added: Optional[List[StrictStr]] = Field(default=None, description="List of files added in this commit")
    author: Optional[PayloadUser] = None
    committer: Optional[PayloadUser] = None
    id: Optional[StrictStr] = Field(default=None, description="sha1 hash of the commit")
    message: Optional[StrictStr] = Field(default=None, description="The commit message")
    modified: Optional[List[StrictStr]] = Field(default=None, description="List of files modified in this commit")
    removed: Optional[List[StrictStr]] = Field(default=None, description="List of files removed in this commit")
    timestamp: Optional[datetime] = None
    url: Optional[StrictStr] = Field(default=None, description="The URL to view this commit")
    verification: Optional[PayloadCommitVerification] = None
    __properties: ClassVar[List[str]] = ["added", "author", "committer", "id", "message", "modified", "removed", "timestamp", "url", "verification"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PayloadCommit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of author
        if self.author:
            _dict['author'] = self.author.to_dict()
        # override the default output from pydantic by calling `to_dict()` of committer
        if self.committer:
            _dict['committer'] = self.committer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of verification
        if self.verification:
            _dict['verification'] = self.verification.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PayloadCommit from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "added": obj.get("added"),
            "author": PayloadUser.from_dict(obj["author"]) if obj.get("author") is not None else None,
            "committer": PayloadUser.from_dict(obj["committer"]) if obj.get("committer") is not None else None,
            "id": obj.get("id"),
            "message": obj.get("message"),
            "modified": obj.get("modified"),
            "removed": obj.get("removed"),
            "timestamp": obj.get("timestamp"),
            "url": obj.get("url"),
            "verification": PayloadCommitVerification.from_dict(obj["verification"]) if obj.get("verification") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.commit import Commit  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestCommit(unittest.TestCase):
    """Commit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Commit
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Commit`
        """
        model = py_gitea_opensuse_org.models.commit.Commit()  # noqa: E501
        if include_optional :
            return Commit(
                author = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', ), 
                commit = py_gitea_opensuse_org.models.repo_commit_contains_information_of_a_commit_in_the_context_of_a_repository/.RepoCommit contains information of a commit in the context of a repository.(
                    author = py_gitea_opensuse_org.models.commit_user_contains_information_of_a_user_in_the_context_of_a_commit/.CommitUser contains information of a user in the context of a commit.(
                        date = '', 
                        email = '', 
                        name = '', ), 
                    committer = py_gitea_opensuse_org.models.commit_user_contains_information_of_a_user_in_the_context_of_a_commit/.CommitUser contains information of a user in the context of a commit.(
                        date = '', 
                        email = '', 
                        name = '', ), 
                    message = '', 
                    tree = py_gitea_opensuse_org.models.commit_meta_contains_meta_information_of_a_commit_in_terms_of_api/.CommitMeta contains meta information of a commit in terms of API.(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        sha = '', 
                        url = '', ), 
                    url = '', 
                    verification = py_gitea_opensuse_org.models.payload_commit_verification.PayloadCommitVerification(
                        payload = '', 
                        reason = '', 
                        signature = '', 
                        signer = py_gitea_opensuse_org.models.payload_user.PayloadUser(
                            email = '', 
                            name = '', 
                            username = '', ), 
                        verified = True, ), ), 
                committer = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', ), 
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                files = [
                    py_gitea_opensuse_org.models.commit_affected_files.CommitAffectedFiles(
                        filename = '', )
                    ], 
                html_url = '', 
                parents = [
                    py_gitea_opensuse_org.models.commit_meta_contains_meta_information_of_a_commit_in_terms_of_api/.CommitMeta contains meta information of a commit in terms of API.(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        sha = '', 
                        url = '', )
                    ], 
                sha = '', 
                stats = py_gitea_opensuse_org.models.commit_stats.CommitStats(
                    additions = 56, 
                    deletions = 56, 
                    total = 56, ), 
                url = ''
            )
        else :
            return Commit(
        )
        """

    def testCommit(self):
        """Test Commit"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.21.0-rc1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from py_gitea_opensuse_org.models.markup_option import MarkupOption


class TestMarkupOption(unittest.TestCase):
    """MarkupOption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MarkupOption:
        """Test MarkupOption
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `MarkupOption`
        """
        model = MarkupOption()
        if include_optional:
            return MarkupOption(
                context = '',
                file_path = '',
                mode = '',
                text = '',
                wiki = True
            )
        else:
            return MarkupOption(
        )
        """

    def testMarkupOption(self):
        """Test MarkupOption"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_workflow_job import ActionWorkflowJob

class TestActionWorkflowJob(unittest.TestCase):
    """ActionWorkflowJob unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionWorkflowJob:
        """Test ActionWorkflowJob
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionWorkflowJob`
        """
        model = ActionWorkflowJob()
        if include_optional:
            return ActionWorkflowJob(
                completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                conclusion = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                head_branch = '',
                head_sha = '',
                html_url = '',
                id = 56,
                labels = [
                    ''
                    ],
                name = '',
                run_attempt = 56,
                run_id = 56,
                run_url = '',
                runner_id = 56,
                runner_name = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = '',
                steps = [
                    py_gitea_opensuse_org.models.action_workflow_step.ActionWorkflowStep(
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conclusion = '', 
                        name = '', 
                        number = 56, 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', )
                    ],
                url = ''
            )
        else:
            return ActionWorkflowJob(
        )
        """

    def testActionWorkflowJob(self):
        """Test ActionWorkflowJob"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.user_settings_options import (
    UserSettingsOptions,
)  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestUserSettingsOptions(unittest.TestCase):
    """UserSettingsOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserSettingsOptions
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `UserSettingsOptions`
        """
        model = py_gitea_opensuse_org.models.user_settings_options.UserSettingsOptions()  # noqa: E501
        if include_optional :
            return UserSettingsOptions(
                description = '', 
                diff_view_style = '', 
                full_name = '', 
                hide_activity = True, 
                hide_email = True, 
                language = '', 
                location = '', 
                theme = '', 
                website = ''
            )
        else :
            return UserSettingsOptions(
        )
        """

    def testUserSettingsOptions(self):
        """Test UserSettingsOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.25.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CreateStatusOption(BaseModel):
    """
    CreateStatusOption holds the information needed to create a new CommitStatus for a Commit
    """ # noqa: E501
    context: Optional[StrictStr] = Field(default=None, description="Context is the unique context identifier for the status")
    description: Optional[StrictStr] = Field(default=None, description="Description provides a brief description of the status")
    state: Optional[StrictStr] = Field(default=None, description="State represents the status state to set (pending, success, error, failure) pending CommitStatusPending  CommitStatusPending is for when the CommitStatus is Pending success CommitStatusSuccess  CommitStatusSuccess is for when the CommitStatus is Success error CommitStatusError  CommitStatusError is for when the CommitStatus is Error failure CommitStatusFailure  CommitStatusFailure is for when the CommitStatus is Failure warning CommitStatusWarning  CommitStatusWarning is for when the CommitStatus is Warning skipped CommitStatusSkipped  CommitStatusSkipped is for when CommitStatus is Skipped")
    target_url: Optional[StrictStr] = Field(default=None, description="TargetURL is the URL to link to for more details")
    __properties: ClassVar[List[str]] = ["context", "description", "state", "target_url"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['pending', 'success', 'error', 'failure', 'warning', 'skipped']):
            raise ValueError("must be one of enum values ('pending', 'success', 'error', 'failure', 'warning', 'skipped')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateStatusOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateStatusOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "context": obj.get("context"),
            "description": obj.get("description"),
            "state": obj.get("state"),
            "target_url": obj.get("target_url")
        })
        return _obj


